# GWASpy

<!-- badges: start -->
![install status](https://github.com/atgu/GWASpy/actions/workflows/install-ci.yml/badge.svg)
![PyPI version](https://badge.fury.io/py/gwaspy.svg)

Genome-wide association studies pypeline (GWASpy): A Python package for performing GWAS QC, PCA, haplotype phasing, and
genotype imputation.

## Installation
GWASpy is available through [PyPI](https://pypi.org/project/gwaspy/). To install, run the command:
```bash
pip3 install gwaspy
```

## Usage
For usage, please visit [GWASpy](https://gwaspy.readthedocs.io/)

## Copyright and License
GWASpy is generously distributed under the [MIT License](https://github.com/atgu/GWASpy/blob/main/LICENSE)